package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: Mar 15, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func NewClient(
broker string,
username string,
password string,
isSource bool,
clientName string,
cleanSession bool,
onConnectHandler func(paho.Client),
onConnectionLostHandler func(paho.Client, error),
) (paho.Client, error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.